@@ -1,13 +1,13 @@
 #!/usr/bin/env python3
+import argparse
 import os
 import subprocess
-import argparse as _argparse
 
 from siriushlacon.regatron.consts import COMPLETE_MAIN, REGATRON_DEVICES
 
 os.environ["PYDM_DEFAULT_PROTOCOL"] = "ca://"
 
-parser = _argparse.ArgumentParser(description="Run SI PS DCLink Interface.")
+parser = argparse.ArgumentParser(description="Run SI PS DCLink Interface.")
 parser.add_argument("-dev", "--device", type=str, default="")
 parser.add_argument("--master", action="store_true")
 args = parser.parse_args()
